pub trait Codec {
// Required method
fn codec_name<T>(&self) -> String;
}Expand description
Define a codec type and implement the Codec trait
Required Methods
fn codec_name<T>(&self) -> String
Object Safety
This trait is not object safe.
pub trait Codec {
// Required method
fn codec_name<T>(&self) -> String;
}Define a codec type and implement the Codec trait